function [A,M,SS,C]=matrixStokesRIG(v1,t1,nv2,ib2,icT,nu)
%--------------------------------------------------------------------------
% Construction des matrices de Stokes   
%--------------------------------------------------------------------------

nv1=size(v1,1); nt1=size(t1,1);

tstart=tic;
fprintf('-----------------------------------------------------------\n');
fprintf('Construction des matrices de Stokes                        \n');
fprintf('-----------------------------------------------------------\n');
fprintf('Construction des matrices P2 : ');

[DxDx,DyDy,DxDy,DxW,DyW,SS]=matrixP2vect(v1,t1);

fprintf('Construction des matrices P1 : ');

[DxDxP1,DyDyP1,WW]=matrixP1vect(v1,t1);

fprintf('Temps d''assemblage des matrices P1 et P2: %f s\n',toc(tstart));

% Matrices de Stokes : formulation D(u):D(v)

tstart=tic;
A=[(nu*2)*DxDx+nu*DyDy nu*DxDy' -DxW;
    nu*DxDy  nu*DxDx+(2*nu)*DyDy -DyW;
    -DxW'       -DyW'        sparse(nv1,nv1)];

M =blkdiag(SS,SS,sparse(nv1,nv1));

fprintf('Temps de construction des matrices de Stokes: %f s\n',toc(tstart));

% Calcul de la moyenne de la pression (multiplicateur de Lagrange)

un=ones(nv1,1);
w=zeros(nv1,1);
for k=1:nt1
    pt=t1(k,1:3);
    aire=t1(k,5);
    w(pt)=w(pt)+aire/3;
end
%C=[sparse(2*(nv2-length(ib2)),1);w/(w'*un)];
C=[sparse(2*nv2,1);w/(w'*un)];

% Gestion des conditions limites :
%
% Dans la matrice A de Stokes, on ne retient que les noeuds interieurs 
% (i.e. les noeuds qui ne sont pas sur le bord).
% Remarque : L'instruction A=A(icT,:); A=A(:,icT) est beaucoup plus 
%            rapide que l'instruction A(ibT,:)=[];A(:,ibT)=[]; qui 
%            consiste à supprimer les noeuds du bord.

tstart=tic;
A=A(icT,:); A=A(:,icT);
M=M(icT,:); M=M(:,icT);
C=C(icT);

fprintf('Temps de traitement des CL: %f s\n',toc(tstart));

end

