%-------------------------------------------------------------------------
% Post-traitement des résultats du solveur IFS fluide/rigide "mainRIG"
% Lecture de fichiers; affichage des solutions
%-------------------------------------------------------------------------
%
close all;
clear all;

fprintf('-------------------------------------------------------\n');
fprintf('              Interaction fluide/rigide                \n');
fprintf('   Lecture des fichiers de données / Post-traitement   \n');
fprintf('-------------------------------------------------------\n');

% Répertoire des fichiers à lire'
dir_name='Results';
% Racine des fichiers
file_name='Rigid';
% Choix de l'affichage : 1-> vitesse; 2-> pression
type_affichage=1;
% Choix de l'echelle d'affichage (pour la vitesse)
fixscale=true;
% Création d'une vidéo
video=false;

% Lecture des données de base (paramètres numériques, maillages,...)
nom_fich=strcat(dir_name,'/',file_name,'_numdata.dat');
S=load(nom_fich,'-ASCII');
nbiter=S(1); pas_h=S(2); nu=S(3); 
nom_fich=strcat(dir_name,'/',file_name,'_v2.dat');
load(nom_fich,'v2','-mat');
nom_fich=strcat(dir_name,'/',file_name,'_t2.dat');
load(nom_fich,'t2','-mat');
nom_fich=strcat(dir_name,'/',file_name,'_v1.dat');
load(nom_fich,'v1','-mat');
nom_fich=strcat(dir_name,'/',file_name,'_t1.dat');
load(nom_fich,'t1','-mat');
nom_fich=strcat(dir_name,'/',file_name,'_vcr0.dat');
load(nom_fich,'vcr0','-mat');

nv1=size(v1,1); nv2=size(v2,1);
nt1=size(t1,1); nt2=size(t2,1); 

%---------------------
% Lecture des données
%---------------------
Uxf=zeros(nv2,nbiter+1); Uyf=Uxf;
mod_U=zeros(nv2,nbiter+1);
maxmodU=0;
Pression=zeros(nv1,nbiter+1);
maxPr=-inf;
minPr=+inf;

fprintf('Lecture des données\n');
rep=input(sprintf('Nombre de fichiers à lire [%d] : ',nbiter));
if ~isempty(rep),
    nbiter=rep;
end
fprintf('(1...20)=');
ntt=floor(nbiter/20)*20; j=1;

for it=1:nbiter+1
    
    if (mod(it*20,ntt)==0)
       fprintf(strcat(num2str(j),' '));
       j=j+1;
    end
    
    % Lecture de la vitesse
    nom_fich=sprintf('%s/%s_Ux_%.4d.dat',dir_name,file_name,it-1);
    load(nom_fich,'Ux','-mat');
    Uxf(:,it)=Ux;
    nom_fich=sprintf('%s/%s_Uy_%.4d.dat',dir_name,file_name,it-1);
    load(nom_fich,'Uy','-mat');
    Uyf(:,it)=Uy;
    mod_U(:,it)=sqrt(Ux.^2+Uy.^2);
    mmod=max(mod_U(:,it));
    if mmod> maxmodU, maxmodU=mmod; end;
       
    % Lecture de la pression
    nom_fich=sprintf('%s/%s_P_%.4d.dat',dir_name,file_name,it-1);
    load(nom_fich,'P','-mat')
    Pression(:,it)=P;
    minp=min(P); maxp=max(P);
    if maxp> maxPr, maxPr=maxp; end;
    if minp< minPr, minPr=minp; end;
end

fprintf('\nValeur max. du module de la vitesse = %f \n',maxmodU);

% Lecture des positions et vitesses du solide
nom_fich_position=strcat(dir_name,'/',file_name,'_position.dat');
fid = fopen(nom_fich_position,'rt');
Hpos=fscanf(fid,'%e %e %e',[3 inf]); 
fclose(fid);
nom_fich_vitesse=strcat(dir_name,'/',file_name,'_vitesse.dat');
fid = fopen(nom_fich_vitesse,'rt');
Hvel=fscanf(fid,'%e %e %e',[3 inf]);
fclose(fid);

% Lecture des pas de temps
nom_fich=strcat(dir_name,'/',file_name,'_dt.dat');
fid = fopen(nom_fich,'rt');
DT=fscanf(fid,'%e',[1 inf]);
fclose(fid);

if length(DT)>1,
    tps=(1:nbiter).*DT(1:nbiter);
else
    tps=(1:nbiter)*DT
end;
tps=[0 tps];

%---------------
%   Affichage
%---------------
set(gcf,'Position',[10,10,800,600])
set(gcf,'Color',[1 1 1]);  % Figure's background color = white
colormap('jet');

nbptx=20;
nbpty=40;
xd=linspace(0,max(v1(:,1)),nbptx);
yd=linspace(0,max(v1(:,2)),nbpty);
[Xgrid,Ygrid] = meshgrid(xd,yd);

while 1
   
   fprintf('Affichage en cours...\n');
      
   for it=1:nbiter+1
       
      clf
      if type_affichage==1
          
         % Affichage du module de la vitesse
         
         patch('faces',t2(:,1:3),'vertices',v2(:,1:2),'FaceVertexCData',...
                mod_U(:,it),'facecolor','interp','edgecolor','none');
         %patch('faces',t1(:,1:3),'vertices',v1(:,1:2),'FaceVertexCData',...
         %       mod_U(1:nv1,it),'facecolor','interp','edgecolor','none');
         
         % Affichage du maillage    
         %patch('faces',t1(:,1:3),'vertices',v1(:,1:2),'facecolor','none','edgecolor','black');
         
         if fixscale
            set(gca,'CLim',[0,maxmodU]);
         end;
         hold on
    
         % Affichage du champ de vitesse sur le maillage P1
         quiver(v1(:,1),v1(:,2),Uxf(1:nv1,it),Uyf(1:nv1,it),'black');
         
%          % Affichage du champ de vitesse sur une grille (interpolation)
%          % construction de l'interpolant
%          Fx = TriScatteredInterp(v1(:,1),v1(:,2),Uxf(1:nv1,it));
%          Fy = TriScatteredInterp(v1(:,1),v1(:,2),Uyf(1:nv1,it));
%          % evaluation de l'interpolant aux noeuds de (xd,yd) de la grille
%          Uxgrid=Fx(Xgrid,Ygrid);
%          Uygrid=Fy(Xgrid,Ygrid);
%          quiver(Xgrid,Ygrid,Uxgrid,Uygrid,'r');
          
          message=sprintf('vitesse à t=%f (k=%d)\n',tps(it),it);
          hold off
         
      else
          
         % Affichage de la pression
         
         patch('faces',t1(:,1:3),'vertices',v1(:,1:2),'FaceVertexCData',...
               Pression(:,it),'facecolor','interp','edgecolor','black');
         %set(gca,'CLim',[minPr,maxPr]);
         message=sprintf('pression à t=%f (k=%d)\n',tps(it),it);
         
      end
      
      % Affichage du solide
      
      % changement du repere du rigide au repere global
      xG=Hpos(1,it);
      yG=Hpos(2,it);
      theta=Hpos(3,it);
      Rr=[cos(theta) sin(theta);-sin(theta) cos(theta)];
      vcr(:,1)=xG+vcr0(:,1:2)*Rr(:,1);
      vcr(:,2)=yG+vcr0(:,1:2)*Rr(:,2);
      hold on
      
      % Affichage du contour du rigide
      
      fill(vcr(:,1),vcr(:,2),'black');
      %plot(vcr(:,1),vcr(:,2),'black','LineWidth',2);
      
      %nn=size(vcr,1);
      %nn=floor(nn/2);
      %fill(vcr(1:nn,1),vcr(1:nn,2),'black');
      %fill(vcr(nn:end,1),vcr(nn:end,2),'white');
      
      hold off
      axis image
      colorbar('northoutside');
      title(message)
      drawnow
          
      % Sauvegarde de l'affichage pour la vidéo
      if video, F(it)=getframe(gcf); end;
      
   end
   
   % Affichage de la trajectoire du centre du rigide
   figure(2); clf;
   plot(tps,Hvel(2,1:nbiter+1));
   title('Vitesse verticale');
   figure(3); clf;
   plot(tps,Hvel(1,1:nbiter+1));
   title('Vitesse horizontale');
   figure(4); clf;
   plot(Hpos(1,1:nbiter+1),Hpos(2,1:nbiter+1));
   title('Trajectoire du centre de masse');
   axis equal
   
   reply = input('Encore une fois? O/N [N]: ', 's');
   if ((reply~='O' & reply~='o') | isempty(reply)), break; end;
   
end

% Visionnage de la vidéo. Utiliser movie2avi pour creer un fichier vidéo
if video
   fprintf('----------------------------------------------------------\n');
   fprintf('Création du fichier vidéo...\n');
   movie(F,1)
   message=strcat(dir_name,'/',file_name,'.avi');
   imparsec=floor(1/dt);
   movie2avi(F,message,'FPS',imparsec,'compression','none')
end


